@@ -5,95 +5,97 @@ from enum import auto
 import logging
 
 from appdirs import AppDirs
-
 from pychromecast.controllers.media import MediaStatus
 from pychromecast.controllers.receiver import CastStatus
 from pychromecast import Chromecast, get_chromecasts, \
   get_chromecast_from_host
-
 from mpris_server.base import AutoName
 
 
-NAME = 'chromecast_mpris'
+Seconds = int
 
-RC_NO_CHROMECAST = 1
-NO_DURATION = 0
-NO_DELTA = 0
-NO_CHROMECAST_NAME = "NO_NAME"
-FIRST_CHROMECAST = 0
 
-DESKTOP_SUFFIX = '.desktop'
+NAME: str = 'chromecast_mpris'
+DESKTOP_NAME: str = 'Cast Control'
+LOG_LEVEL: str = 'WARN'
 
-SRC_DIR = Path(__file__).parent
-ASSETS_DIR = SRC_DIR / "assets"
-DESKTOP_FILE_LOCAL = ASSETS_DIR / f"{NAME}{DESKTOP_SUFFIX}"
+RC_NO_CHROMECAST: int = 1
+RC_NOT_RUNNING: int = 2
 
-ICON_DIR = ASSETS_DIR / 'icon'
-LIGHT_THUMB = LIGHT_ICON = ICON_DIR / 'cc-white.png'
-DEFAULT_THUMB = DARK_ICON = ICON_DIR / 'cc-black.png'
+NO_DURATION: float = 0.0
+NO_DELTA: int = 0
+NO_CHROMECAST_NAME: str = 'NO_NAME'
+NO_STR: str = ''
+NO_PORT: Optional[int] = None
+NO_DEVICE: str = 'Device'
+
+YOUTUBE: str = 'YouTube'
+
+US_IN_SEC: int = 1_000_000  # seconds to microseconds
+DEFAULT_TRACK: str = '/track/1'
+DEFAULT_DISC_NO: int = 1
+
+DEFAULT_RETRY_WAIT: float = 5.0
+DEFAULT_WAIT: Seconds = 30
+
+DESKTOP_SUFFIX: str = '.desktop'
+NO_DESKTOP_FILE: str = ''
 
 APP_DIRS = AppDirs(NAME)
 DATA_DIR = Path(APP_DIRS.user_data_dir)
-DESKTOP_FILE_DATA = DATA_DIR / DESKTOP_FILE_LOCAL.name
+
+if not DATA_DIR.exists():
+  DATA_DIR.mkdir()
+
+PID: Path = DATA_DIR / f'{NAME}.pid'
+
+SRC_DIR = Path(__file__).parent
+ASSETS_DIR: Path = SRC_DIR / 'assets'
+DESKTOP_FILE_LOCAL: Path = ASSETS_DIR / f'{NAME}{DESKTOP_SUFFIX}'
+
+ICON_DIR: Path = ASSETS_DIR / 'icon'
+LIGHT_THUMB = LIGHT_ICON = ICON_DIR / 'cc-white.png'
+DEFAULT_THUMB = DARK_ICON = ICON_DIR / 'cc-black.png'
+
+DESKTOP_FILE_DATA: Path = DATA_DIR / DESKTOP_FILE_LOCAL.name
 
 
 def create_desktop_file(light_icon: bool = True) -> Path:
-  if not DATA_DIR.exists():
-    DATA_DIR.mkdir()
-
   if light_icon:
-    icon = str(LIGHT_ICON.absolute())
+    icon_path = str(LIGHT_ICON.absolute())
     file = DATA_DIR / f'{NAME}-light{DESKTOP_SUFFIX}'
 
   else:
-    icon = str(DARK_ICON.absolute())
+    icon_path = str(DARK_ICON.absolute())
     file = DATA_DIR / f'{NAME}-dark{DESKTOP_SUFFIX}'
 
   if not file.exists():
-    *lines, last = DESKTOP_FILE_LOCAL \
+    *lines, name, icon = DESKTOP_FILE_LOCAL \
       .read_text() \
       .splitlines()
 
-    last += icon
-    lines = (*lines, last)
+    name += DESKTOP_NAME
+    icon += icon_path
+    lines = (*lines, name, icon)
     data = '\n'.join(lines)
+
     file.write_text(data)
 
   return file
 
 
+DESKTOP_FILE_LIGHT: Optional[Path] = None
+DESKTOP_FILE_DARK: Optional[Path] = None
+
 try:
   DESKTOP_FILE_LIGHT = create_desktop_file(light_icon=True)
   DESKTOP_FILE_DARK = create_desktop_file(light_icon=False)
 
 except Exception as e:
   logging.exception(e)
-  logging.warn(f"Couldn't create {DATA_DIR} or {DESKTOP_FILE_DATA}.")
-
-  DESKTOP_FILE_LIGHT = DESKTOP_FILE_DARK = Path()
+  logging.warn(f"Couldn't create {DESKTOP_SUFFIX} files in {DATA_DIR}.")
 
 
-#DEFAULT_THUMB = \
-  #'https://upload.wikimedia.org/wikipedia/commons/thumb/2/26/Chromecast_cast_button_icon.svg/500px-Chromecast_cast_button_icon.svg.png'
-#LIGHT_THUMB = \
-  #'https://alexdelorenzo.dev/assets/imgs/projects/chromecast_mpris/cc-white.png'
-
-
-YOUTUBE = "YouTube"
-
-NO_STR = ''
-NO_PORT = None
-
-LOG_LEVEL: str = 'WARN'
-
-US_IN_SEC = 1_000_000  # seconds to microseconds
-DEFAULT_TRACK = "/track/1"
-DEFAULT_DISC_NO = 1
-
-DEFAULT_RETRY_WAIT: float = 5.0
-
-
-Seconds = int
 Status = Union[MediaStatus, CastStatus]
 
 
